MethodChannelInstantRequestHandler class

An implementation of InstantRequestHandlerPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
requestEvents Stream<Map<String, dynamic>>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermissions() Future<InstantRequestPermissionStatus>
override
clearPendingRequest({String? requestId}) Future<void>
override
configureNotificationTypes(List<Map<String, dynamic>> notificationTypes) Future<void>
override
getPendingRequest() Future<Map<String, dynamic>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBatteryOptimizationSettings() Future<void>
override
openFullScreenIntentSettings() Future<void>
override
openOverlaySettings() Future<void>
override
requestNotificationPermission() Future<void>
override
showNativeNotification(Map<String, dynamic> payload) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited