InstantRequestHandlerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- InstantRequestHandlerPlatform
- Implementers
Constructors
- InstantRequestHandlerPlatform()
- Constructs a InstantRequestHandlerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestEvents
→ Stream<
Map< String, dynamic> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPermissions(
) → Future< InstantRequestPermissionStatus> -
clearPendingRequest(
{String? requestId}) → Future< void> -
configureNotificationTypes(
List< Map< notificationTypes) → Future<String, dynamic> >void> -
getPendingRequest(
) → Future< Map< String, dynamic> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openBatteryOptimizationSettings(
) → Future< void> -
openFullScreenIntentSettings(
) → Future< void> -
openOverlaySettings(
) → Future< void> -
requestNotificationPermission(
) → Future< void> -
showNativeNotification(
Map< String, dynamic> payload) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ InstantRequestHandlerPlatform
-
The default instance of InstantRequestHandlerPlatform to use.
getter/setter pair